.. include:: references.txt

`astropy.io.votable.exceptions`
*******************************

.. contents::

.. automodule:: astropy.io.votable.exceptions

Exception utilities
===================

.. currentmodule:: astropy.io.votable.exceptions

.. autofunction:: warn_or_raise

.. autofunction:: vo_raise

.. autofunction:: vo_reraise

.. autofunction:: vo_warn

.. autofunction:: parse_vowarning

.. autoclass:: VOWarning
   :show-inheritance:

.. autoclass:: VOTableChangeWarning
   :show-inheritance:

.. autoclass:: VOTableSpecWarning
   :show-inheritance:

.. autoclass:: UnimplementedWarning
   :show-inheritance:

.. autoclass:: IOWarning
   :show-inheritance:

.. autoclass:: VOTableSpecError
   :show-inheritance:
